@@ -1,12 +1,18 @@
-# Copyright (C) 2018-2019 SignalFx, Inc. All rights reserved.
+# Copyright (C) 2018-2019 SignalFx. All rights reserved.
 
 instrumented_attr = '__sfx_instrumented'
 traceable_libraries = (
     'celery', 'django', 'elasticsearch', 'flask', 'psycopg2', 'pymongo', 'pymysql', 'redis', 'requests',
-    'tornado'
+    'tornado', 'logging'
 )
 
 auto_instrumentable_libraries = (
     'celery', 'elasticsearch', 'flask', 'psycopg2', 'pymongo', 'pymysql', 'redis', 'requests',
-    'tornado'
+    'tornado', 'logging'
+)
+
+logging_format = (
+    '%(asctime)s %(levelname)s [%(name)s] [%(filename)s:%(lineno)d] '
+    '[signalfx.trace_id=%(sfxTraceId)s signalfx.span_id=%(sfxSpanId)s] '
+    '- %(message)s'
 )
